@@ -4,7 +4,6 @@ from datetime import datetime
 import requests
 from os import path
 
-
 def json_parameters_function():
     def inner(func):
         def wrapper(json_object):
@@ -352,6 +351,25 @@ class JsonList(list):
                 nl.append(i)
         return nl
 
+    def find_first(self, l):
+        return self[self.find_first_index(l)]
+
+    def find_first_index(self, l):
+        for ix, i in enumerate(self):
+            if l(i):
+                return ix
+        raise RuntimeError("Value not found")
+
+    def find_ordered(self, l, value):
+        return self[self.find_ordered_index(l, value)]
+
+    def find_ordered_index(self, l, value):
+        from bisect import bisect_left
+        i = bisect_left(self, value, key=l)
+        if i < 0 or i >= len(self) or l(self[i]) != value:
+            raise RuntimeError("Value %s not found" % str(value))
+        return i
+
     def process(self, l):
         nl = JsonList()
         for i in self:
@@ -408,12 +426,12 @@ class JsonList(list):
         if self.list_type is int or self.list_type is float or self.list_type is bool:
             return array(self)
         if issubclass(self.list_type, JsonObject):
-            return array([i.get_numeric_values() for i in self])
+            return array([i.get_values() for i in self])
         raise "Numpy conversion can only be done on typed json lists with types float, int, bool or JsonObject"
 
     def from_numpy_array(self, a):
         self.clear()
-        columns = self.list_type().get_numeric_columns()
+        columns = self.list_type().get_columns()
         for row in a:
             ni = self.list_type()
             for i, c in enumerate(columns):
